@@ -45,7 +45,7 @@ DEFAULTS = {
     'DEBUG_TOOLBAR': False,
     'SHOW_DEBUG_TOOLBAR': False,
     'LOG_OUTPUT_REQUESTS': True,
-    'AUTO_GENERATE_TASKS_FOR_DJANGO_COMMANDS': (),
+    'AUTO_GENERATE_TASKS_FOR_DJANGO_COMMANDS': {},
     'CELERY_HEALTH_CHECK_DEFAULT_QUEUE': getattr(django_settings, 'CELERY_DEFAULT_QUEUE', 'default'),
 }
 
